from setuptools import setup

setup(name='neovim',
      version='0.3.1',
      description='Transition packgage for pynvim',
      url='http://github.com/neovim/python-client',
      author='Thiago de Arruda',
      author_email='tpadilha84@gmail.com',
      license='Apache',
      packages=[],
      install_requires=['pynvim>=0.3.1'],
      zip_safe=False)
